# -*- coding: utf-8 -*-

# (C) Djordjevic Nebojsa <nesh@studioquattro.co.yu> 2005
# You're welcome to redistribute this software under the
# terms of the GNU Library General Public Licence version 2.0
# or, at your option, any higher version.
#
# You can read the complete GNU LGPL in the file COPYING
# which should come along with this software, or visit
# the Free Software Foundation's WEB site http://www.fsf.org
#

""" l10n functions

    based on locale python module
"""

##################################################
## DEPENDENCIES ##

import os

# get some locale data froms python locale module
import filecache
from pylocale import normalize, _parse_localename

##################################################
## GLOBALS AND CONSTANTS ##

# init cache
_locale_cache = filecache.FileCache()

##################################################
## CLASSES ##

# I can't able to find another source so here is (AIX)
# LC_COLLATE format: http://publib.boulder.ibm.com/infocenter/pseries/topic/com.ibm.aix.doc/files/aixfiles/LC_COLLATE.htm#bjq6320bob
# LC_MONETARY format: http://publib.boulder.ibm.com/infocenter/pseries/topic/com.ibm.aix.doc/files/aixfiles/LC_MONETARY.htm#fjq6260bob
# LC_TIME format: http://publib.boulder.ibm.com/infocenter/pseries/topic/com.ibm.aix.doc/files/aixfiles/LC_TIME.htm#ljq680bob
# LC_NUMERIC format: http://publib.boulder.ibm.com/infocenter/pseries/topic/com.ibm.aix.doc/files/aixfiles/LC_NUMERIC.htm#ujq6260bob

class _BaseLC(object):
    def __init__(self, path=None):
        super(_BaseLC, self).__init__()
    #

    def _parse(self, data):
        raise NotImplementedError
    #
    
    def _load(self, path, name):
        """ parse LC_xxx files """
        path = os.path.join(path, name)
        content = _locale_cache.load(path, 'rU')

        # strip ws, empty lines and commentd
        lines = [l.strip() for l in content.split('\n')]

        if not lines: # empty file
            return {}
        #
        
        if lines[0] != name:
            return {}
        else: # delete header and footer
            del lines[0]
            del lines[-1]
        #

        ret = {}
        for line in lines:
            if line == '': continue
            if line.startswith('#'): continue
            if line == 'END ' + name: break

            kw, data = line.split(' ', 1)
            
            if '"' in data: # strip "
                data = data[1:-1]
            #
            
            ret[kw.strip()] = data.strip()
        # for

        return ret
    # _load
#
