# -*- coding: utf-8 -*-

# (C) Djordjevic Nebojsa <nesh@studioquattro.co.yu> 2005
# You're welcome to redistribute this software under the
# terms of the GNU Library General Public Licence version 2.0
# or, at your option, any higher version.
#
# You can read the complete GNU LGPL in the file COPYING
# which should come along with this software, or visit
# the Free Software Foundation's WEB site http://www.fsf.org
#

""" l10n functions

    based on locale python module
"""

##################################################
## DEPENDENCIES ##

import os
from pylocale import normalize, _parse_localename

from numeric import _Numeric
from monetary import _Monetary

##################################################
## GLOBALS AND CONSTANTS ##

# current locale
_locale = None

##################################################
## CLASSES ##

class _Locale(object):
    """ store info about locale """
    
    def __init__(self, name='C', path=None):
        super(_Locale, self).__init__()

        self._name = normalize(name)

        if path is not None:
            self._numeric = _Numeric(path=path)
            self._monetary = _Monetary(path=path)
        else:
            self._numeric = _Numeric()
            self._monetary = _Numeric()
    # __init__

    def _get_numeric(self):
        return self._numeric
    #
    numeric = property(fget=_get_numeric)

    def _get_monetary(self):
        return self._monetary
    #
    monetary = property(fget=_get_monetary)

    def _get_name(self):
        """ return normalized locale name """
        return _parse_localename(self._name)[0]
    #
    language = property(fget=_get_name)

    def _get_encoding(self):
        """ return locale encoding """
        return _parse_localename(self._name)[1]
    #
    encoding = property(fget=_get_encoding)
# _Locale

# Locale emulation

##################################################
## FUNCTIONS ##

def set_locale(locale=None, path=None):
    global _locale

    if locale is None:
        _locale = _Locale()
        return
    #
    
    if path is None:
        try:
            # try to find out location of message files
            import django.conf.settings
            my_dir = os.path.dirname(__file__)
            # I'm in django.core, so locale dir is ../locale/
            path = getattr(django.conf.settings, 'LOCALE_DIR',
                           os.path.join(os.path.abspath(os.path.join(my_dir, '..')), 'locale'))
        except ImportError:
            path = ''
    #

    _locale = _Locale(locale, os.path.join(path, locale))
# set_locale

## setup global locale
if _locale is None:
    set_locale()
#

def get_locale():
    return _locale
#
